==> kubernetes-model-autoscaling-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ExternalMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExternalMetricStatusFluent<A extends ExternalMetricStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent();
  public MetricValueStatus buildCurrent();
  public A withCurrent(MetricValueStatus current);
  public Boolean hasCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> withNewCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
  public ExternalMetricStatusFluent.CurrentNested<A> editCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public ExternalMetricStatusFluent.MetricNested<A> withNewMetric();
  public ExternalMetricStatusFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public ExternalMetricStatusFluent.MetricNested<A> editMetric();
  public ExternalMetricStatusFluent.MetricNested<A> editOrNewMetric();
  public ExternalMetricStatusFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CurrentNested<N> extends Nested<N>,MetricValueStatusFluent<ExternalMetricStatusFluent.CurrentNested<N>>{
    public N and();
    public N endCurrent();
    
  }
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<ExternalMetricStatusFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ExternalMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExternalMetricStatusFluent<A extends ExternalMetricStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCurrent instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricValueStatus getCurrent();
  public MetricValueStatus buildCurrent();
  public A withCurrent(MetricValueStatus current);
  public Boolean hasCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> withNewCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
  public ExternalMetricStatusFluent.CurrentNested<A> editCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
  public ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public ExternalMetricStatusFluent.MetricNested<A> withNewMetric();
  public ExternalMetricStatusFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public ExternalMetricStatusFluent.MetricNested<A> editMetric();
  public ExternalMetricStatusFluent.MetricNested<A> editOrNewMetric();
  public ExternalMetricStatusFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CurrentNested<N> extends Nested<N>,MetricValueStatusFluent<ExternalMetricStatusFluent.CurrentNested<N>>{
    public N and();
    public N endCurrent();
    
  }
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<ExternalMetricStatusFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  
}
